/*
 * mcf5282.h -- Definitions for Motorola Coldfire 5282
 *
 * Based on mcf5282sim.h of uCLinux distribution:
 *      (C) Copyright 1999, Greg Ungerer (gerg@snapgear.com)
 *
 * See file CREDITS for list of people who contributed to this
 * project.
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License as
 * published by the Free Software Foundation; either version 2 of
 * the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston,
 * MA 02111-1307 USA
 */

/****************************************************************************/
#ifndef	m5282_h
#define	m5282_h
/****************************************************************************/

/*
 * Size of internal RAM
 */

#define INT_RAM_SIZE	65536

#define mbar_readLong(x)      *((volatile unsigned long *) (CFG_MBAR + x))
#define mbar_readShort(x)     *((volatile unsigned short *) (CFG_MBAR + x))
#define mbar_readByte(x)      *((volatile unsigned char *) (CFG_MBAR + x))
#define mbar_writeLong(x,y)   *((volatile unsigned long *) (CFG_MBAR + x)) = y
#define mbar_writeShort(x,y)  *((volatile unsigned short *) (CFG_MBAR + x)) = y
#define mbar_writeByte(x,y)   *((volatile unsigned char *) (CFG_MBAR + x)) = y

/*
 *	Define the 5282 SIM register set addresses.
 */
#define	MCFICM_INTC0		0x0c00		/* Base for Interrupt Ctrl 0 */
#define	MCFICM_INTC1		0x0d00		/* Base for Interrupt Ctrl 0 */
#define	MCFINTC_IPRH		0x00		/* Interrupt pending 32-63 */
#define	MCFINTC_IPRL		0x04		/* Interrupt pending 1-31 */
#define	MCFINTC_IMRH		0x08		/* Interrupt mask 32-63 */
#define	MCFINTC_IMRL		0x0c		/* Interrupt mask 1-31 */
#define	MCFINTC_INTFRCH		0x10		/* Interrupt force 32-63 */
#define	MCFINTC_INTFRCL		0x14		/* Interrupt force 1-31 */
#define	MCFINTC_IRLR		0x18		/* */
#define	MCFINTC_IACKL		0x19		/* */
#define	MCFINTC_ICR0		0x40		/* Base ICR register */

#define	MCFINT_UART0		13		/* Interrupt number for UART0 */
#define	MCFINT_PIT1		55		/* Interrupt number for PIT1 */

#define MCFGPTA_PORT		0x1A001D
#define MCFGPTA_DDR		0x1A001E


/*************************************************************
 * GPIO
 *************************************************************/
#define MCFGPIO_DDRUA		0x100025


/**
 * PAR's
 *************************************/
#define MCFGPIO_PBCDPAR  	0x100050
#define MCFGPIO_PFPAR  		0x100051
#define MCFGPIO_PEPAR  		0x100052
#define MCFGPIO_PJPAR  		0x100054
#define MCFGPIO_PSDPAR  	0x100055
#define MCFGPIO_PASPAR  	0x100056
#define MCFGPIO_PEHLPAR  	0x100058
#define MCFGPIO_PQSPAR  	0x100059
#define MCFGPIO_PTCPAR  	0x10005A
#define MCFGPIO_PTDPAR  	0x10005B
#define MCFGPIO_PUAPAR  	0x10005C
/*************************************************************/

#define MCFSCM_RAMBAR           (0x00000008)
#define MCFSCM_CRSR		(0x00000010)
#define MCFSCM_CRSR_EXT		(0x80)
#define MCFSCM_CRSR_CWDR	(0x20)
#define MCFSCM_RAMBAR_BA(x)     ((x)&0xFFFF0000)
#define MCFSCM_RAMBAR_BDE       (0x00000200)

#define MCFRESET_RCR		(0x00110000)
#define MCFRESET_RSR		(0x00110001)

#define MCFRESET_RCR_SOFTRST    (0x80)
#define MCFRESET_RCR_FRCRSTOUT  (0x40)
#define MCFRESET_RCR_LVDF       (0x10)
#define MCFRESET_RCR_LVDIE      (0x08)
#define MCFRESET_RCR_LVDRE      (0x04)
#define MCFRESET_RCR_LVDE       (0x01)
#define MCFRESET_RSR_LVD        (0x40)
#define MCFRESET_RSR_SOFT       (0x20)
#define MCFRESET_RSR_WDR        (0x10)
#define MCFRESET_RSR_POR        (0x08)
#define MCFRESET_RSR_EXT        (0x04)
#define MCFRESET_RSR_LOC        (0x02)
#define MCFRESET_RSR_LOL        (0x01)
#define MCFRESET_RSR_ALL        (0x7F)
#define MCFRESET_RCR_SOFTRST    (0x80)
#define MCFRESET_RCR_FRCRSTOUT  (0x40)

#define MCFCLOCK_SYNCR          0x120000
#define MCFCLOCK_SYNSR          0x120002

#define MCFCLOCK_SYNCR_MFD(x)   (((x)&0x0007)<<12)
#define MCFCLOCK_SYNSR_LOCK     0x08

#define MCFSDRAMC_DCR		0x40
#define MCFSDRAMC_DACR0		0x48
#define MCFSDRAMC_DMR0		0x4c
#define MCFSDRAMC_DACR1		0x50
#define MCFSDRAMC_DMR1		0x54

#define MCFSDRAMC_DCR_NAM	(0x2000)
#define MCFSDRAMC_DCR_COC	(0x1000)
#define MCFSDRAMC_DCR_IS	(0x0800)
#define MCFSDRAMC_DCR_RTIM_3	(0x0000)
#define MCFSDRAMC_DCR_RTIM_6	(0x0200)
#define MCFSDRAMC_DCR_RTIM_9	(0x0400)
#define MCFSDRAMC_DCR_RC(x)	((x)&0x01FF)

#define MCFSDRAMC_DACR_BASE(x)	((x)&0xFFFC0000)
#define MCFSDRAMC_DACR_RE	(0x00008000)
#define MCFSDRAMC_DACR_CASL(x)	(((x)&0x03)<<12)
#define MCFSDRAMC_DACR_CBM(x)	(((x)&0x07)<<8)
#define MCFSDRAMC_DACR_PS_32	(0x00000000)
#define MCFSDRAMC_DACR_IP	(0x00000008)
#define MCFSDRAMC_DACR_IMRS	(0x00000040)

#define MCFSDRAMC_DMR_BAM_16M	(0x00FC0000)
#define MCFSDRAMC_DMR_WP        (0x00000100)
#define MCFSDRAMC_DMR_CI        (0x00000040)
#define MCFSDRAMC_DMR_AM        (0x00000020)
#define MCFSDRAMC_DMR_SC        (0x00000010)
#define MCFSDRAMC_DMR_SD        (0x00000008)
#define MCFSDRAMC_DMR_UC        (0x00000004)
#define MCFSDRAMC_DMR_UD        (0x00000002)
#define MCFSDRAMC_DMR_V         (0x00000001)

#define MCFWTM_WCR              (0x00140000)
#define MCFWTM_WMR              (0x00140002)
#define MCFWTM_WCNTR            (0x00140004)
#define MCFWTM_WSR              (0x00140006)

#define MCFSIM_CSAR0		(0x00000080)
#define MCFSIM_CSMR0		(0x00000084)
#define MCFSIM_CSCR0		(0x0000008a)

#define MCFCFM_MCR		(0x1D0000)
#define MCFCFM_CLKD		(0x1D0002)
#define MCFCFM_SEC		(0x1D0008)
#define MCFCFM_PROT		(0x1D0010)
#define MCFCFM_SACC		(0x1D0014)
#define MCFCFM_DACC		(0x1D0018)
#define MCFCFM_USTAT		(0x1D0020)
#define MCFCFM_CMD		(0x1D0024)

/****************************************************************************/
#endif	/* m5282_h */
