/*
 * Configuation settings for the uC5282
 *
 * (C) Copyright 2005 Zachary P. Landau <kapheine@hypa.net>
 * 
 * Based on M5282EVB.h by Josef Baumgartner
 *
 * See file CREDITS for list of people who contributed to this
 * project.
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License as
 * published by the Free Software Foundation; either version 2 of
 * the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston,
 * MA 02111-1307 USA
 */

/*
 * board/config.h - configuration options, board specific
 */

#ifndef _CONFIG_UC5282_H
#define _CONFIG_UC5282_H

/*
 * High Level Configuration Options
 * (easy to change)
 */
#define	CONFIG_MCF52x2			/* define processor family */
#define CONFIG_M5282			/* define processor type */

#define INTERNAL_BOOT

#define FEC_ENET
#define CONFIG_NET_RETRY_COUNT 5

/* Some values are duplicated under different names for uCbootloader compatibility
   These will probably be phased out at some point.
   serial# is set once.  Later on, this value should be unset so that some other
   process can set a serial# for each board.
   ethaddr should probably be set by the same process that sets serial#
 */
#define CONFIG_IPADDR 192.168.0.205
#define CONFIG_SERVERIP 192.168.0.132
#define CONFIG_ETHADDR 00:06:3b:00:44:27
#define CONFIG_EXTRA_ENV_SETTINGS \
	"CONSOLE=ttyS0\0" \
	"FACTORY=Labx Technologies, LLC\0" \
	"serial#=SETTHIS\0" \
	"KERNEL_ARGS=root=/dev/mtdblock0\0" \
	"IPADDR0=192.168.0.205\0" 

#define CONFIG_BAUDRATE 9600
//#define CONFIG_WATCHDOG
#define CONFIG_WATCHDOG_TIMEOUT 3905 /* Should be ~500ms */
#define CFG_BAUDRATE_TABLE { 9600 , 19200 , 38400 , 57600, 115200 }

#undef CONFIG_MONITOR_IS_IN_RAM	/* define if monitor is started from a pre-loader */

/* Configuration for environment
 * Environment is embedded in u-boot in the second sector of the flash
 */
#define CFG_ENV_ADDR		0xf0020000
#define CFG_ENV_SIZE		(2*1024)
#define CFG_ENV_SECT_SIZE       (2*1024)
#define CFG_ENV_IS_IN_FLASH	1
#define CFG_MAX_FLASH_SECT      256
#define	CFG_MAX_FLASH_BANKS	2
#define	CFG_FLASH_ERASE_TOUT	10000000


#define CONFIG_COMMANDS  (( CONFIG_CMD_DFL | CFG_CMD_PING | CFG_CMD_MII | CFG_CMD_JFFS2 | CFG_AUTO_COMPLETE) & ~(CFG_CMD_LOADS | CFG_CMD_LOADB | CFG_FLASH_PROTECTION))

#define CFG_JFFS2_FIRST_BANK 0
#define CFG_JFFS2_NUM_BANKS 1

/* this must be included AFTER the definition of CONFIG_COMMANDS (if any) */
#include <cmd_confdefs.h>
#define CONFIG_BOOTDELAY	5

#define CFG_PROMPT		"u-boot # "
#define	CFG_LONGHELP				/* undef to save memory		*/

#if (CONFIG_COMMANDS & CFG_CMD_KGDB)
#define	CFG_CBSIZE		1024		/* Console I/O Buffer Size	*/
#else
#define	CFG_CBSIZE		256		/* Console I/O Buffer Size	*/
#endif
#define	CFG_PBSIZE (CFG_CBSIZE+sizeof(CFG_PROMPT)+16) /* Print Buffer Size */
#define	CFG_MAXARGS		16		/* max number of command args	*/
#define CFG_BARGSIZE		CFG_CBSIZE	/* Boot Argument Buffer Size	*/

#define CFG_LOAD_ADDR		0x40000

#define CFG_DRAM_TEST
#define CFG_MEMTEST_START	0x400
#define CFG_MEMTEST_END		0x3000        /* increase this */

#define CFG_HZ			1000000
#define	CFG_CLK			64000000
#define MHZCLOCK		64		/* system bus frequency in MHz */


/*
 * Low Level Configuration Settings
 * (address mappings, register initial values, etc.)
 * You should know what you are doing if you make changes here.
 */
#define	CFG_MBAR		0x40000000

#define CFG_DISCOVER_PHY
#define	CFG_ENET_BD_BASE	0x380000

/*-----------------------------------------------------------------------
 * Definitions for initial stack pointer and data area (in DPRAM)
 */
#define CFG_INIT_RAM_ADDR       0x20000000
#define CFG_INIT_RAM_END	0x10000		/* End of used area in internal SRAM	*/
#define CFG_GBL_DATA_SIZE	64      	/* size in bytes reserved for initial data */
#define CFG_GBL_DATA_OFFSET	(CFG_INIT_RAM_END - CFG_GBL_DATA_SIZE)
#define CFG_INIT_SP_OFFSET	CFG_GBL_DATA_OFFSET

#define CFG_SRAM_BASE           CFG_INIT_RAM_ADDR
/*-----------------------------------------------------------------------
 * Start addresses for the final memory configuration
 * (Set up by the startup code)
 * Please note that CFG_SDRAM_BASE _must_ start at 0
 */
#define CFG_SDRAM_BASE		0x00000000
#define	CFG_SDRAM_SIZE		8		/* SDRAM size in MB */
#define CFG_FLASH_BASE		0x10000000
#define CFG_FLASH_SIZE          0x00100000
#define CFG_FLASH_CFI 1
#define CFG_FLASH_CFI_DRIVER 1
#define CFG_FLASH_CFM_DRIVER 1
#define CFG_FLASH_BANKS_LIST { CFG_FLASH_BASE, CFG_INT_FLASH_BASE }

#define	CFG_INT_FLASH_BASE	0xf0000000

/* If M5282 port is fully implemented the monitor base will be behind
 * the vector table. */
#define CFG_MONITOR_BASE        (CFG_INT_FLASH_BASE + 0x400)

#define CFG_MONITOR_LEN		0x20000
#define CFG_MALLOC_LEN		(256 << 10)
#define CFG_BOOTPARAMS_LEN	64*1024


/*
 * For booting Linux, the board info and command line data
 * have to be in the first 8 MB of memory, since this is
 * the maximum mapped by the Linux kernel during initialization ??
 */
#define	CFG_BOOTMAPSZ		(8 << 20)	/* Initial Memory map for Linux	*/

/*-----------------------------------------------------------------------
 * Cache Configuration
 */
#define CFG_CACHELINE_SIZE	16

/*-----------------------------------------------------------------------
 * Memory bank definitions 
 */
#define CFG_CSAR0 0x1000
#define CFG_CSMR0 0x00ff0001
#define CFG_CSCR0 0x3d80

/*-----------------------------------------------------------------------
 * Port configuration
 */
#define CFG_PEHLPAR	0xC0  /* Enable ethernet signals */
#define CFG_PUAPAR	0x0F  /* Enable UART */
#define CFG_DDRUA	0x05  /* Set DDR for UART */
#define CFG_PBCDPAR  0xC0  
#define CFG_PJPAR  0xFF  
#define CFG_PASPAR  0x0f0A  


#endif	/* _CONFIG_UC5282_H */
